==> contrast_agent-8.6.0.tar.gz: contrast_agent-8.6.0/src/contrast/reporting/teamserver_messages/application_inventory.py <==
# Copyright © 2024 Contrast Security, Inc.
# See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
from typing import Set
import requests

from .base_ts_message import BaseTsAppMessage
from contrast.utils.decorators import fail_loudly
from contrast.api import Route
from contrast_vendor import structlog as logging

logger = logging.getLogger("contrast")


class ApplicationInventory(BaseTsAppMessage):
    def __init__(self, routes: Set[Route]):
        # This message does not need "Application-Path" header, but it doesn't hurt
        # either.
        super().__init__()
        # TODO: PYT-3324 update to 1.1 when TeamServer can accept it
        self.base_url = f"{self.settings.api_url}/agents/v1.0/"

        self.body = {
            "routes": [route.to_json_inventory() for route in routes],
        }

        session_id = self.settings.config.session_id
        if session_id:
            self.body.update({"session_id": session_id})

    @property
    def name(self):
        return "application-inventory"

    @property
    def path(self):
        return "/".join(
            [
                "applications",
                self.server_name_b64,
                self.server_path_b64,
                self.server_type_b64,
                self.app_language_b64,
                self.app_name_b64,
                "inventory",
            ]
        )

    @property
    def request_method(self):
        return requests.Session.post

    @fail_loudly("Failed to process ApplicationInventory response")
    def process_response(self, response, reporting_client):
        self.process_response_code(response, reporting_client)

==> contrast_agent-9.2.0.tar.gz: contrast_agent-9.2.0/src/contrast/reporting/teamserver_messages/application_inventory.py <==
# Copyright © 2024 Contrast Security, Inc.
# See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
from dataclasses import asdict
from typing import Set
from contrast_fireball import DiscoveredRoute
import requests

from .base_ts_message import BaseTsAppMessage
from contrast.utils.decorators import fail_loudly
from contrast_vendor import structlog as logging

logger = logging.getLogger("contrast")


class ApplicationInventory(BaseTsAppMessage):
    def __init__(self, routes: Set[DiscoveredRoute]):
        # This message does not need "Application-Path" header, but it doesn't hurt
        # either.
        super().__init__()
        self.base_url = f"{self.settings.api_url}/agents/v1.1/"

        self.body = {
            "routes": [asdict(route) for route in routes],
        }

        session_id = self.settings.config.session_id
        if session_id:
            self.body.update({"session_id": session_id})

    @property
    def name(self):
        return "application-inventory"

    @property
    def path(self):
        return "/".join(
            [
                "applications",
                self.server_name_b64,
                self.server_path_b64,
                self.server_type_b64,
                self.app_language_b64,
                self.app_name_b64,
                "inventory",
            ]
        )

    @property
    def request_method(self):
        return requests.Session.post

    @fail_loudly("Failed to process ApplicationInventory response")
    def process_response(self, response, reporting_client):
        self.process_response_code(response, reporting_client)
